@@ -1,4 +1,4 @@
-/* 15nov12abu
+/* 06may13abu
  * (c) Software Lab. Alexander Burger
  */
 
@@ -344,6 +344,27 @@ any doUp(any x) {
    return *val;
 }
 
+// (sys 'any ['any]) -> sym
+any doSys(any x) {
+   any y;
+
+   y = evSym(x = cdr(x));
+   {
+      char nm[bufSize(y)];
+
+      bufString(y,nm);
+      if (!isCell(x = cdr(x)))
+         return mkStr(getenv(nm));
+      y = evSym(x);
+      {
+         char val[bufSize(y)];
+
+         bufString(y,val);
+         return setenv(nm,val,1)? Nil : y;
+      }
+   }
+}
+
 /*** Primitives ***/
 any circ(any x) {
    any y = x;
@@ -459,7 +480,7 @@ int compare(any x, any y) {
       if (isCell(y) || y == T)
          return -1;
       if (!isNum(a = name(x)))
-         return !isNum(name(y))? 1664525*(int32_t)(long)x - 1664525*(int32_t)(long)y : -1;
+         return !isNum(name(y))? (long)x - (long)y : -1;
       if (!isNum(b = name(y)))
          return +1;
       n1 = unDig(a), n2 = unDig(b);
@@ -496,6 +517,32 @@ int compare(any x, any y) {
    }
 }
 
+int binSize(any x) {
+   if (isNum(x)) {
+      int n = numBytes(x);
+
+      if (n < 63)
+         return n + 1;
+      return n + 2 + (n - 63) / 255;
+   }
+   else if (isNil(x))
+      return 1;
+   else if (isSym(x))
+      return binSize(name(x));
+   else {
+      any y = x;
+      int n = 2;
+
+      while (n += binSize(car(x)), !isNil(x = cdr(x))) {
+         if (x == y)
+            return n + 1;
+         if (!isCell(x))
+            return n + binSize(x);
+      }
+      return n;
+   }
+}
+
 /*** Error handling ***/
 void err(any ex, any x, char *fmt, ...) {
    va_list ap;
@@ -914,16 +961,15 @@ any doDate(any ex) {
    any x, z;
    int y, m, d, n;
    cell c1;
-   time_t tim;
 
    if (!isCell(x = cdr(ex))) {
-      time(&tim);
-      TM = localtime(&tim);
+      gettimeofday(&Tv,NULL);
+      TM = localtime(&Tv.tv_sec);
       return mkDat(TM->tm_year+1900,  TM->tm_mon+1,  TM->tm_mday);
    }
    if ((z = EVAL(car(x))) == T) {
-      time(&tim);
-      TM = gmtime(&tim);
+      gettimeofday(&Tv,NULL);
+      TM = gmtime(&Tv.tv_sec);
       return mkDat(TM->tm_year+1900,  TM->tm_mon+1,  TM->tm_mday);
    }
    if (isNil(z))
@@ -966,12 +1012,11 @@ any doTime(any ex) {
    any x, z;
    int h, m, s;
    cell c1;
-   time_t tim;
    struct tm *p;
 
    if (!isCell(x = cdr(ex))) {
-      time(&tim);
-      p = localtime(&tim);
+      gettimeofday(&Tv,NULL);
+      p = localtime(&Tv.tv_sec);
       return boxCnt(p->tm_hour * 3600 + p->tm_min * 60 + p->tm_sec);
    }
    if ((z = EVAL(car(x))) == T)
@@ -992,8 +1037,10 @@ any doTime(any ex) {
    return mkTime(h, m, isCell(cdr(x))? evCnt(ex, cdr(x)) : 0);
 }
 
-// (usec) -> num
-any doUsec(any ex __attribute__((unused))) {
+// (usec ['flg]) -> num
+any doUsec(any ex) {
+   if (!isNil(EVAL(cadr(ex))))
+      return boxCnt(Tv.tv_usec);
    gettimeofday(&Tv,NULL);
    return boxWord2((word2)Tv.tv_sec*1000000 + Tv.tv_usec - USec);
 }
