@@ -1,4 +1,4 @@
-/* 20oct11abu
+/* 06feb13abu
  * (c) Software Lab. Alexander Burger
  */
 
@@ -6,6 +6,8 @@
 
 #include <netdb.h>
 #include <arpa/inet.h>
+#include <netinet/in.h>
+#include <sys/socket.h>
 
 static void ipErr(any ex, char *s) {
    err(ex, NULL, "IP %s error: %s", s, strerror(errno));
@@ -72,6 +74,9 @@ static any tcpAccept(int sd) {
       socklen_t len = sizeof(addr);
       if ((sd2 = accept(sd, (struct sockaddr*)&addr, &len)) >= 0) {
          fcntl(sd, F_SETFL, f);
+#ifndef __linux__
+         fcntl(sd2, F_SETFL, 0);
+#endif
          inet_ntop(AF_INET6, &addr.sin6_addr, s, INET6_ADDRSTRLEN);
          val(Adr) = mkStr(s);
          initInFile(sd2,NULL), initOutFile(sd2);
